@@ -9,7 +9,7 @@ class Taos:
         self.db = db
         self.user = user
         self.password = password
-        self.port = port,
+        self.port = port
         self.url = "http://%s:%s/rest/sql/%s" % (self.host, self.port, self.db)
 
     def restful_execute(
@@ -110,3 +110,5 @@ class Taos:
         df_map_columns_cols = ['uuid', 'name', 'display_name', 'user_name'] + df_map_columns_cols
         assert df_taos_columns_cols == df_map_columns_cols, f"字典表 {map_path} 与 数据库超级表 {stable} 的 tag 不匹配, df_map: {df_map_columns_cols}, df_taos: {df_taos_columns_cols}"
         print(f"检查OK: {map_path}")
+
+
